@@ -6,7 +6,7 @@ from schemadiff.changes import Change
 from schemadiff.diff.schema import Schema
 from schemadiff.schema_loader import SchemaLoader
 from schemadiff.formatting import print_diff, format_diff
-from schemadiff.validation import validate_diff
+from schemadiff.validation import validate_changes
 
 
 SDL = str  # Alias for string describing schema through schema definition language
@@ -39,6 +39,6 @@ __all__ = [
     'diff_from_file',
     'format_diff',
     'print_diff',
-    'validate_diff',
+    'validate_changes',
     'Change',
 ]
