@@ -1,7 +1,8 @@
 from schemadiff.changes import Change, Criticality
 
-class SchemaChange:
-    criticality: Criticality.breaking('Changing a root type is a breaking change')
+
+class SchemaChange(Change):
+    criticality = Criticality.breaking('Changing a root type is a breaking change')
 
     def __init__(self, old_type, new_type):
         self.old_type = old_type
